==> haskell-network-control-0.1.3-14.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.1.3
visibility:           public
id:                   network-control-0.1.3-Hts72k10EnKIVPk1rEcNCA
key:                  network-control-0.1.3-Hts72k10EnKIVPk1rEcNCA
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  80d7a0f1043655a06768014728063509
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-control-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-control-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-control-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.1.3-Hts72k10EnKIVPk1rEcNCA
depends:
    base-4.18.2.1 psqueues-0.2.8.2-7Hsdb7lcqdu8EEvCE8H06F
    unix-time-0.4.17-Hz2xrJUYyRaFNdjGOcUMp2

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-control-0.1.3-16-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-control
version:              0.1.3
visibility:           public
id:                   network-control-0.1.3-FQv7ufgIESmKhgBnRdMPqy
key:                  network-control-0.1.3-FQv7ufgIESmKhgBnRdMPqy
license:              BSD-3-Clause
maintainer:           kazu@iij.ad.jp
author:               Kazu Yamamoto
synopsis:             Library to control network protocols
description:          Common parts to control network protocols
category:             Network
abi:                  9c38ef72bf9219ee228be267566f5adb
exposed:              True
exposed-modules:      Network.Control
hidden-modules:
    Network.Control.Flow Network.Control.LRUCache Network.Control.Rate

import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-control-0.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-control-0.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-control-0.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-control
hs-libraries:         HSnetwork-control-0.1.3-FQv7ufgIESmKhgBnRdMPqy
depends:
    base-4.18.2.1 psqueues-0.2.8.2-8uu3DxPW2eP1IKqIpq0lUH
    unix-time-0.4.17-1fbhzfcTn8QIpITXkAFa5Z

haddock-interfaces:
    /usr/share/doc/haskell-network-control/html/network-control.haddock

haddock-html:         /usr/share/doc/haskell-network-control/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
